@@ -5,7 +5,7 @@
 use strict;
 use lib '../../lib';
 
-use OpenFrame::Config;
+use OpenFrame;
 use OpenFrame::Server::HTTP;
 
 my $config = OpenFrame::Config->new();
@@ -29,10 +29,10 @@ $config->setKey(
 		  config   => {
 			       installed_applications => [
 							  {
-							   name      => 'eliza',
+							   namespace => 'eliza',
 							   uri       => '/',
 							   dispatch  => 'Local',
-							   namespace => 'Eliza::Application',
+							   name      => 'Eliza::Application',
 							  },
 							 ],
 			      },
@@ -75,7 +75,7 @@ Leon Brocard <leon@fotango.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2001, Fotango Ltd.
+Copyright (C) 2001-2, Fotango Ltd.
 
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
