@@ -2,14 +2,14 @@ package Hangman::Generator;
 
 use strict;
 use OpenFrame::Config;
-use OpenFrame::AbstractResponse;
+use OpenFrame::Response;
 use OpenFrame::Constants;
 use Template;
 
 my $tt;
 
 sub what {
-  return ['OpenFrame::Session', 'OpenFrame::AbstractRequest', 'OpenFrame::AbstractCookie'];
+  return ['OpenFrame::Session', 'OpenFrame::Request', 'OpenFrame::Cookietin'];
 }
 
 sub action {
@@ -50,7 +50,7 @@ sub action {
   delete $session->{template}; # delete spurious entry by TT
 
 
-  my $response = OpenFrame::AbstractResponse->new();
+  my $response = OpenFrame::Response->new();
   $response->message($output);
   $response->code(ofOK);
   $response->mimetype('text/html');
@@ -87,7 +87,7 @@ Leon Brocard <leon@fotango.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2001, Fotango Ltd.
+Copyright (C) 2001-2, Fotango Ltd.
 
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
