@@ -25,10 +25,10 @@ OpenFrame::Constants - Constants for OpenFrame
 
 =head1 SYNOPSIS
 
-  use OpenFrame::AbstractResponse;
+  use OpenFrame::Response;
   use OpenFrame::Constants;
 
-  my $response = OpenFrame::AbstractResponse->new();
+  my $response = OpenFrame::Response->new();
   $response->message($output);
   $response->code(ofOK);
   $response->mimetype('text/html');
@@ -41,10 +41,10 @@ use inside OpenFrame.
 
 =head1 CONSTANTS
 
-=head2 OpenFrame::AbstractResponse constants
+=head2 OpenFrame::Response constants
 
 The following constants are valid as codes of an
-C<OpenFrame::AbstractResponse> object:
+C<OpenFrame::Response> object:
 
 =over 4
 
@@ -72,7 +72,7 @@ James A. Duncan <jduncan@fotango.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2001, Fotango Ltd.
+Copyright (C) 2001-2, Fotango Ltd.
 
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
