@@ -15,13 +15,17 @@ use Apache::Cookie;
 use Apache::Request;
 use Apache::Constants qw ( :response );
 
+use OpenFrame;
 use OpenFrame::Server;
 use OpenFrame::Constants;
-use OpenFrame::AbstractCookie;
-use OpenFrame::AbstractRequest;
-use OpenFrame::AbstractResponse;
+use OpenFrame::Cookietin;
+use OpenFrame::Request;
+use OpenFrame::Response;
+
+our $VERSION = 2.01;
+
+Apache::add_version_component("OpenFrame/" . $OpenFrame::VERSION);
 
-our $VERSION = (split(/ /, q{$Id: Apache.pm,v 1.18 2002/01/09 11:37:51 leon Exp $ }))[2];
 
 sub handler {
   my $request = shift;
@@ -29,12 +33,12 @@ sub handler {
   ##
   ## make sure we have a valid request
   ##
-  if (!$request || !blessed( $request) || !$request->isa('Apache')) {
+  unless (blessed( $request)) {
     warn("invalid call to handler") if $OpenFrame::DEBUG;
     return undef;
   }
 
-  my $url = 'http://' . $request->hostname . $request->uri;
+  my $url = 'http://' . $request->hostname . ':' . $request->get_server_port . $request->uri;
 
   my $uri = URI->new( $url );
   if ($uri) {
@@ -55,14 +59,14 @@ sub handler {
   my $args = { map { ($_, $ar->param($_)) } $ar->param() };
   $args{$_->name} = $_->fh foreach $ar->upload;
 
-  my $cookietin  = OpenFrame::AbstractCookie->new();
+  my $cookietin  = OpenFrame::Cookietin->new();
   my %apcookies  = Apache::Cookie->fetch();
 
   foreach my $key (keys %apcookies) {
     $cookietin->set($apcookies{$key}->name(), $apcookies{$key}->value());
   }
 
-  my $abstractRequest = OpenFrame::AbstractRequest->new(
+  my $abstractRequest = OpenFrame::Request->new(
 							uri         => $uri,
 							originator  => ref( $request ),
 							descriptive => 'web',
@@ -70,6 +74,7 @@ sub handler {
 							cookies     => $cookietin,
 						       );
 
+
   if (!$abstractRequest) {
     warn("could not create abstract request object") if $OpenFrame::DEBUG;
     return undef;
@@ -78,7 +83,7 @@ sub handler {
 
     my $response = OpenFrame::Server->action( $abstractRequest );
 
-    if (blessed( $response ) && $response->isa( 'OpenFrame::AbstractResponse' )) {
+    if (blessed( $response ) && $response->isa( 'OpenFrame::Response' )) {
       if ($response->code() eq ofOK) {
 	## first prepare the cookie
 
@@ -87,7 +92,7 @@ sub handler {
 	foreach my $name (keys %cookies) {
 	  my $cookie = Apache::Cookie->new(
 					   Apache->request,
-					   -name  => $name,
+					   -name => $name,
 					   -value => $cookies{$name},
 					   -expires => '+1M',
 					   -path    => '/',
@@ -109,11 +114,12 @@ sub handler {
 	warn("[apache] declined") if $OpenFrame::DEBUG;
 	return DECLINED;
       } elsif ($response->code() eq ofREDIRECT) {
-	warn("[apache] redirect") if $OpenFrame::DEBUG;
-	Apache->request()->header_out(
-				      "Location" => $response->message()
-				     );
-	return REDIRECT;
+        my $url = $response->message;
+	warn("[apache] redirect to $url") if $OpenFrame::DEBUG;
+	$request->header_out("Location" => $url);
+        $request->status(REDIRECT);
+	$request->send_http_header;
+	return OK;
       } elsif ($response->code() eq ofERROR) {
 	warn("[apache] server error") if $OpenFrame::DEBUG;
 	warn($response->message()) if $OpenFrame::DEBUG;
@@ -126,7 +132,9 @@ sub handler {
   }
 }
 
-
+sub import {
+  print STDERR "THIS MODULE HAS BEEN USE'd\n";
+}
 1;
 
 __END__
@@ -142,12 +150,12 @@ This is a mod_perl extension, see the INSTALL guide for information on how to in
 =head1 DESCRIPTION
 
 I<OpenFrame::Server::Apache> is an Apache extension.  It is
-responsible for creating an I<OpenFrame::AbstractRequest> object and
+responsible for creating an I<OpenFrame::Request> object and
 passing it back to the main server class.  It also delivers the
-I<OpenFrame::AbstractResponse> object to the client.
+I<OpenFrame::Response> object to the client.
 
 Note that any file upload objects are in the arguments of the
-AbstractRequest and their value is a filehandle pointing to the
+Request and their value is a filehandle pointing to the
 object.
 
 =head1 DEPENDENCIES
@@ -156,7 +164,7 @@ object.
 
 =item Apache
 
-=item OpenFrame::AbstractRequest
+=item OpenFrame::Request
 
 =back
 
